###########################################################################
#
# ExpediteeExportAction.pm -- 
# Based on HTMLToExpediteeAction.pm - Used for exporting INDIVIDUAL
# Greenstone documents to Expeditee. If you want to export an entire
# collection, use HTMLToExpediteeAction.pm.
#
# A component of the Greenstone digital library software
# from the New Zealand Digital Library Project at the 
# University of Waikato, New Zealand.
#
# Copyright (C) 2009 New Zealand Digital Library Project
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#
###########################################################################

package ExpediteeExportAction;

use strict;

use cgiactions::baseaction;

use ExpediteeFrameIO;
use JSON;

use Devel::Peek;

BEGIN {
#    unshift (@INC, "$ENV{'GSDLHOME'}/perllib/cpan/perl-5.8");
}

@ExpediteeExportAction::ISA = ('baseaction');

# c=collect and site=xxxx implicitly handled by code
# 'c' is handled by base action, site is tested for only if greenstone3.

my $action_table=
{
	    "generate-frame"     => { 'compulsory-args' => [ "fn", "json" ],
			      'optional-args'   => [] }, 
};

sub new
{
    my $class = shift (@_);
    my ($gsdl_cgi,$iis6_mode) = @_;

    my $self = new baseaction($action_table,$gsdl_cgi,$iis6_mode);

    return bless $self, $class;
}

sub generate_frame
{
	my $self = shift @_;
	
	my $username  = $self->{'username'};
    my $collect   = $self->{'collect'};
    my $gsdl_cgi  = $self->{'gsdl_cgi'};
    my $gsdlhome  = $self->{'gsdlhome'};

    my $site = $self->{'site'};
    my $collect_dir = $gsdl_cgi->get_collection_dir($site);

    my $fn = $self->{'fn'};
	
	my $json_str_unicode = $self->{'json'}; 
	
	my $found = $self->{'found'};
	
	 if (!Encode::is_utf8( $json_str_unicode )) {
         $json_str_unicode = Encode::decode_utf8( $json_str_unicode );
     }
	 
	# decode_json expects string to convert to be raw utf8
    my $json_str_utf8 = Encode::encode("utf8",$json_str_unicode);
    my $exp_frame_tree = decode_json $json_str_utf8;	
    
    my $output_dir = &util::filename_cat($collect_dir,$collect,"export");

    if (!-d $output_dir) {
	&util::mk_dir($output_dir);
    }

    my $expeditee_frame_io = new ExpediteeFrameIO($output_dir,"kgas1A");
	
	 $expeditee_frame_io->buildFrame($exp_frame_tree);
	 
	 if($expeditee_frame_io->saveFrame("$fn.exp")){
		#need to determine if $fn is followed by another number or $fn is the last number in the frameset.
	 
		#if $fn is last number, write out next free frame num
		unless($found){
			#write out next free frame num
			$expeditee_frame_io->saveLastFrameNumber($fn);
		}
				
		#otherwise just carry on.
		
		$gsdl_cgi->generate_message("Item Exported to Expeditee $fn");
	 }else{
		$gsdl_cgi->generate_error("Failed to save frame number $fn");
	 }
	 
	 
}

1;